@@ -2,7 +2,8 @@
 
 /*Copyright (c) 2005-2006 Dodji Seketeli
  *
- * Permission is hereby granted, free of charge, to any person obtaining a copy of this
+ * Permission is hereby granted, free of charge,
+ * to any person obtaining a copy of this
  * software and associated documentation files (the "Software"),
  * to deal in the Software without restriction, including without limitation
  * the rights to use, copy, modify, merge, publish, distribute,
@@ -10,7 +11,8 @@
  * persons to whom the Software is furnished to do so,
  * subject to the following conditions:
  *
- * The above copyright notice and this permission notice shall be included in all copies
+ * The above copyright notice and this permission
+ * notice shall be included in all copies
  * or substantial portions of the Software.
  *
  * THE SOFTWARE IS PROVIDED "AS IS",
@@ -46,9 +48,9 @@ struct ModuleRegistry::Priv {
     map<UString, GModule*> library_cache  ;
 };//end ModuleRegistry::Priv
 
-ModuleRegistry::ModuleRegistry ()
+ModuleRegistry::ModuleRegistry () :
+    m_priv (new ModuleRegistry::Priv)
 {
-    m_priv = new ModuleRegistry::Priv ;
 }
 
 ModuleRegistry::~ModuleRegistry ()
@@ -83,13 +85,13 @@ struct DynamicModule::Loader::Priv {
     DynamicModuleManager * module_manager ;
 
     Priv () :
-        module_manager (NULL)
+        module_manager (0)
     {}
 };//end struct Loader::Priv
 
-DynamicModule::Loader::Loader ()
+DynamicModule::Loader::Loader () :
+    m_priv (new Loader::Priv)
 {
-    m_priv = new Loader::Priv ;
 
     //init the module config search path to system config dir
     config_search_paths ().push_back (env::get_system_config_dir ());
@@ -123,7 +125,8 @@ DynamicModule::Loader::module_config (const string &a_module_name)
                                     m_priv->config_map.find (a_module_name) ;
     if (iter == m_priv->config_map.end ()) {
         //we didn't find the module config in config cache.
-        //Let's walk the module conf paths and try to parse module confs from there.
+        //Let's walk the module conf paths
+        //and try to parse module confs from there.
         for (vector<UString>::const_iterator it = config_search_paths ().begin ();
              it != config_search_paths ().end ();
              ++it) {
@@ -131,7 +134,6 @@ DynamicModule::Loader::module_config (const string &a_module_name)
             path_elements.push_back (it->c_str ()) ;
             path_elements.push_back (a_module_name + ".conf") ;
             string path = Glib::build_filename (path_elements) ;
-
             if (!Glib::file_test (path, Glib::FILE_TEST_EXISTS)) {continue;}
 
             result = parse_module_config_file (path.c_str ()) ;
@@ -171,9 +173,13 @@ DynamicModule::Loader::build_library_path (const UString &a_module_name,
     }
 
     for (; it != end ; ++it) {
+        LOG_D ("in directory '" << Glib::locale_from_utf8 (*it) << "' ...",
+               "module-loading-domain") ;
         common::GCharSafePtr system_lib_path
             (g_module_build_path (it->c_str (), a_lib_name.c_str ())) ;
-        if (Glib::file_test (system_lib_path.get (),
+        LOG_D ("looking for library '" << Glib::locale_from_utf8 (system_lib_path.get ()),
+               "module-loading-domain") ;
+        if (Glib::file_test (Glib::filename_from_utf8 (system_lib_path.get ()),
                              Glib::FILE_TEST_EXISTS)) {
             return system_lib_path.get () ;
         }
@@ -189,11 +195,13 @@ DynamicModule::Loader::parse_module_config_file (const UString &a_path)
         THROW ("Got path \"\" to modules config file") ;
     }
 
-    libxmlutils::XMLTextReaderSafePtr reader ;
+    using libxmlutils::XMLTextReaderSafePtr ;
+    using libxmlutils::XMLCharSafePtr ;
+    XMLTextReaderSafePtr reader ;
     UString name ;
     libxmlutils::XMLCharSafePtr xml_str ;
 
-    reader = xmlNewTextReaderFilename (a_path.c_str ()) ;
+    reader.reset (xmlNewTextReaderFilename (a_path.c_str ())) ;
     if (!reader) {
         THROW ("could not create xml reader") ;
     }
@@ -212,14 +220,14 @@ DynamicModule::Loader::parse_module_config_file (const UString &a_path)
     if (!goto_next_element_node_and_check (reader, "name")) {
         THROW ("expected 'name' node as child of 'module' node") ;
     }
-    xml_str = xmlTextReaderReadString (reader.get ()) ;
+    xml_str.reset (xmlTextReaderReadString (reader.get ())) ;
     module_name = reinterpret_cast<const char*> (xml_str.get ()) ;
 
     if (!goto_next_element_node_and_check (reader, "libraryname")) {
         THROW ("expected 'libraryname' node as second child "
                "of 'module' node") ;
     }
-    xml_str = xmlTextReaderReadString (reader.get ()) ;
+    xml_str.reset (xmlTextReaderReadString (reader.get ())) ;
     library_name = reinterpret_cast<const char*> (xml_str.get ()) ;
     if (module_name != "" && library_name != "") {
         config->library_name = library_name ;
@@ -235,7 +243,7 @@ DynamicModule::Loader::parse_module_config_file (const UString &a_path)
     if (name == "customsearchpaths") {
         for (;;) {
             if (goto_next_element_node_and_check (reader, "path")) {
-                xml_str = xmlTextReaderReadString (reader.get ()) ;
+                xml_str.reset (xmlTextReaderReadString (reader.get ())) ;
                 path = reinterpret_cast<const char*> (xml_str.get ()) ;
                 if (path != "") {
                     config->custom_library_search_paths.push_back (path) ;
@@ -252,7 +260,6 @@ UString
 DynamicModule::Loader::module_library_path (const UString &a_module_name)
 {
     UString library_name, library_path ;
-    std::map<UString, UString>::iterator it ;
     DynamicModule::ConfigSafePtr mod_conf = module_config (a_module_name) ;
     THROW_IF_FAIL2 (mod_conf,
                     UString ("couldn't get module config for module ")
@@ -279,6 +286,8 @@ DynamicModule::Loader::load_library_from_path (const UString &a_library_path)
                + ": " + Glib::locale_from_utf8 (g_module_error ())) ;
     }
     g_module_make_resident (module);//we don't want to unload a module for now
+    LOG_D ("loaded module at path: " << Glib::locale_from_utf8 (a_library_path),
+           "module-loading-domain") ;
     return module ;
 }
 
@@ -293,6 +302,7 @@ DynamicModule::Loader::load_library_from_module_name (const UString &a_name)
     if (!lib) {
         THROW (UString ("failed to load shared library ") + library_path) ;
     }
+    LOG_D ("loaded module " << Glib::locale_from_utf8 (a_name), "module-loading-domain") ;
     return lib;
 }
 
@@ -339,6 +349,7 @@ DynamicModule::Loader::create_dynamic_module_instance (GModule *a_module)
     //**********************************************
     //return a safe pointer DynamicModuleSafePtr
     //**********************************************
+    LOG_REF_COUNT (safe_ptr, g_module_name (a_module)) ;
     return safe_ptr ;
 }
 
@@ -352,7 +363,7 @@ DynamicModule::Loader::load (const UString &a_name)
         return DynamicModuleSafePtr (0);
     }
 
-    DynamicModuleSafePtr result = create_dynamic_module_instance (lib) ;
+    DynamicModuleSafePtr result (create_dynamic_module_instance (lib)) ;
     if (result) {
         result->set_module_loader (this) ;
     }
@@ -369,6 +380,7 @@ DynamicModule::Loader::load_from_path (const UString &a_lib_path)
              +a_lib_path+ "'");
         return DynamicModuleSafePtr (0);
     }
+    LOG_D ("loaded module from path: "<< Glib::locale_from_utf8 (a_lib_path), "module-loading-domain") ;
     return create_dynamic_module_instance (lib) ;
 }
 
@@ -385,6 +397,7 @@ public:
 
 struct DynamicModule::Priv {
     UString real_library_path ;
+    UString name;
     DynamicModule::Loader *loader ;
 
     Priv () :
@@ -392,13 +405,14 @@ struct DynamicModule::Priv {
     {}
 };//end struct DynamicModule::Priv
 
-DynamicModule::DynamicModule ()
+DynamicModule::DynamicModule () :
+    m_priv (new DynamicModule::Priv)
 {
-    m_priv = new DynamicModule::Priv ;
 }
 
 DynamicModule::~DynamicModule ()
 {
+    LOG_D ("deleted", "destructor-domain") ;
 }
 const UString&
 DynamicModule::get_real_library_path () const
@@ -414,6 +428,20 @@ DynamicModule::set_real_library_path (const UString &a_path)
     m_priv->real_library_path = a_path ;
 }
 
+void
+DynamicModule::set_name (const UString &a_name)
+{
+    THROW_IF_FAIL (m_priv) ;
+    m_priv->name = a_name;
+}
+
+const UString&
+DynamicModule::get_name () const
+{
+    THROW_IF_FAIL (m_priv) ;
+    return m_priv->name;
+}
+
 void
 DynamicModule::set_module_loader (DynamicModule::Loader *a_loader)
 {
@@ -436,16 +464,16 @@ struct DynamicModuleManager::Priv {
     get_module_loader ()
     {
         if (!loader) {
-            loader = new DefaultModuleLoader ;
+            loader.reset (new DefaultModuleLoader) ;
         }
         THROW_IF_FAIL (loader) ;
         return loader ;
     }
 };//end struct DynamicModuleManager::Priv
 
-DynamicModuleManager::DynamicModuleManager ()
+DynamicModuleManager::DynamicModuleManager () :
+    m_priv (new DynamicModuleManager::Priv)
 {
-    m_priv = new DynamicModuleManager::Priv ;
 }
 
 DynamicModuleManager::~DynamicModuleManager ()
@@ -453,13 +481,10 @@ DynamicModuleManager::~DynamicModuleManager ()
 }
 
 DynamicModuleSafePtr
-DynamicModuleManager::load (const UString &a_name,
-                            DynamicModule::Loader &a_loader)
+DynamicModuleManager::load_module (const UString &a_name,
+                                   DynamicModule::Loader &a_loader)
 {
-    GModule *lib (0) ;
-    DynamicModuleSafePtr result ;
-
-    lib = module_registry ().get_library_from_cache (a_name) ;
+    GModule *lib = module_registry ().get_library_from_cache (a_name) ;
     if (!lib) {
         //dll doesn't exist in library cache.
         //try to load the dll from disk and put it in library cache.
@@ -469,27 +494,57 @@ DynamicModuleManager::load (const UString &a_name,
         }
     }
     if (!lib) {
-        LOG ("could not load the dynamic library of the dynmod '" +a_name+ "'");
-        return result ;
+        LOG_ERROR
+            ("could not load the dynamic library of the dynmod '" +a_name+ "'");
+        return DynamicModuleSafePtr (0);
     }
-
     DynamicModuleSafePtr module = a_loader.create_dynamic_module_instance (lib) ;
     THROW_IF_FAIL (module) ;
+    LOG_REF_COUNT (module, a_name) ;
 
     module->set_module_loader (&a_loader) ;
+    module->set_name (a_name);
+    module->set_real_library_path (a_loader.module_library_path (a_name));
     a_loader.set_dynamic_module_manager (this) ;
+    LOG_REF_COUNT (module, a_name) ;
+
+    LOG_D ("loaded module " << Glib::locale_from_utf8 (a_name),
+            "module-loading-domain") ;
     return module ;
 }
 
 DynamicModuleSafePtr
-DynamicModuleManager::load (const UString &a_name)
+DynamicModuleManager::load_module (const UString &a_name)
 {
-    return load (a_name, *module_loader ()) ;
+    LOG_D ("loading module " << Glib::locale_from_utf8 (a_name),
+           "module-loading-domain") ;
+    return load_module (a_name, *module_loader ()) ;
+}
+
+DynamicModuleManager&
+DynamicModuleManager::get_default_manager ()
+{
+    static DynamicModuleManager s_default_dynmod_mgr ;
+    return s_default_dynmod_mgr ;
 }
 
 DynamicModuleSafePtr
-DynamicModuleManager::load_from_path (const UString &a_library_path,
-                                      DynamicModule::Loader &a_loader)
+DynamicModuleManager::load_module_with_default_manager
+                                            (const UString &a_mod_name,
+                                             DynamicModule::Loader &a_loader)
+{
+    return get_default_manager ().load_module (a_mod_name, a_loader) ;
+}
+
+DynamicModuleSafePtr
+DynamicModuleManager::load_module_with_default_manager (const UString &a_mod_name)
+{
+    return get_default_manager ().load_module (a_mod_name) ;
+}
+
+DynamicModuleSafePtr
+DynamicModuleManager::load_module_from_path (const UString &a_library_path,
+                                             DynamicModule::Loader &a_loader)
 {
     GModule *lib = a_loader.load_library_from_path (a_library_path) ;
     if (!lib) {
@@ -499,14 +554,18 @@ DynamicModuleManager::load_from_path (const UString &a_library_path,
     a_loader.set_dynamic_module_manager (this) ;
     DynamicModuleSafePtr module = a_loader.create_dynamic_module_instance (lib) ;
     module->set_module_loader (&a_loader) ;
+    LOG_D ("loaded module from path " << Glib::locale_from_utf8 (a_library_path),
+           "module-loading-domain") ;
 
     return module;
 }
 
 DynamicModuleSafePtr
-DynamicModuleManager::load_from_path (const UString &a_library_path)
+DynamicModuleManager::load_module_from_path (const UString &a_library_path)
 {
-    return load_from_path (a_library_path, *module_loader ()) ;
+    LOG_D ("loading module from path " << Glib::locale_from_utf8 (a_library_path),
+           "module-loading-domain") ;
+    return load_module_from_path (a_library_path, *module_loader ()) ;
 }
 
 
@@ -520,7 +579,7 @@ DynamicModule::LoaderSafePtr&
 DynamicModuleManager::module_loader ()
 {
     if (!m_priv->loader) {
-        m_priv->loader = new DefaultModuleLoader ;
+        m_priv->loader.reset (new DefaultModuleLoader) ;
     }
     THROW_IF_FAIL (m_priv->loader) ;
     return m_priv->loader ;
