@@ -98,6 +98,7 @@ public:
         Type m_type;
         int m_line;
         int m_nb_times_hit;
+        int m_ignore_count;
 
     public:
         BreakPoint () {clear ();}
@@ -137,6 +138,9 @@ public:
         int nb_times_hit () const {return m_nb_times_hit;}
         void nb_times_hit (int a_nb) {m_nb_times_hit = a_nb;}
 
+        int ignore_count () const {return m_ignore_count;}
+        void ignore_count (int a) {m_ignore_count = a;}
+
         bool is_pending ()
         {
             if (m_address == "<PENDING>") {
@@ -162,6 +166,7 @@ public:
             m_line = 0;
             m_condition.clear ();
             m_nb_times_hit = 0;
+            m_ignore_count = 0;
         }
     };//end class BreakPoint
 
@@ -816,7 +821,7 @@ public:
 
     virtual sigc::signal<void,
                          int/*thread id*/,
-                         const IDebugger::Frame&/*frame in thread*/,
+                         const IDebugger::Frame *const/*frame in thread*/,
                          const UString& /*cookie*/> &
                                              thread_selected_signal () const=0;
 
@@ -959,11 +964,13 @@ public:
 
     virtual void set_solib_prefix_path (const UString &a_name) = 0;
 
-    virtual void load_program (const UString &a_prog_with_args,
+    virtual void load_program (const UString &a_prog,
+                               const vector<UString> &a_args,
                                const UString &a_working_dir) = 0;
 
     virtual void load_program
-                (const vector<UString> &a_argv,
+                (const UString &a_prog,
+                 const vector<UString> &a_argv,
                  const UString &working_dir,
                  const vector<UString> &a_source_search_dirs,
                  const UString &a_tty_path="") = 0;
@@ -1026,6 +1033,21 @@ public:
                                  const UString &a_condition="",
                                  const UString &a_cookie="") = 0;
 
+    virtual void enable_breakpoint (gint a_break_num,
+                                    const UString &a_cookie="") = 0;
+
+    virtual void disable_breakpoint (gint a_break_num,
+                                     const UString &a_cookie="") = 0;
+
+    virtual void set_breakpoint_ignore_count
+                                        (gint a_break_num,
+                                         gint a_ignore_count,
+                                         const UString &a_cookie = "") = 0;
+
+    virtual void delete_breakpoint (const UString &a_path,
+                                    gint a_line_num,
+                                    const UString &a_cookie="") = 0;
+
     virtual void set_watchpoint (const UString &a_expression,
                                  bool a_write = true,
                                  bool a_read = false,
@@ -1038,16 +1060,6 @@ public:
 
     virtual const map<int, BreakPoint>& get_cached_breakpoints () = 0;
 
-    virtual void enable_breakpoint (gint a_break_num,
-                                    const UString &a_cookie="") = 0;
-
-    virtual void disable_breakpoint (gint a_break_num,
-                                     const UString &a_cookie="") = 0;
-
-    virtual void delete_breakpoint (const UString &a_path,
-                                    gint a_line_num,
-                                    const UString &a_cookie="") = 0;
-
     virtual void choose_function_overload (int a_overload_number,
                                            const UString &a_cookie="") = 0;
 
@@ -1062,6 +1074,8 @@ public:
     virtual void select_thread (unsigned int a_thread_id,
                                 const UString &a_cookie="") = 0;
 
+    virtual unsigned int get_current_thread () const = 0;
+
     virtual void select_frame (int a_frame_id,
                                const UString &a_cookie="") = 0;
 
