@@ -243,7 +243,8 @@ test_main (int argc, char **argv)
     //</connect to IDebugger events>
     //******************************
 
-    debugger->load_program ("fooprog", ".") ;
+    vector<UString> args;
+    debugger->load_program ("fooprog", args, ".") ;
     debugger->set_breakpoint ("main") ;
     debugger->set_breakpoint ("func1") ;
     debugger->set_breakpoint ("func2") ;
